" Required for opening buffers vertically with gina-patch
set diffopt+=vertical

nnoremap <Leader>ga  :Gina add %:p<CR>
nnoremap <Leader>gb  :Gina branch<CR>
nnoremap <Leader>gB  :Gina branch -a<CR>
nnoremap <Leader>gc  :Gina commit<CR>
nnoremap <Leader>gC  :Gina checkout -b<SPACE>
nnoremap <Leader>gd  :Gina diff -- %<CR>
nnoremap <Leader>gD  :Gina diff<CR>
nnoremap <Leader>gf  :Gina fetch --all<CR>
nnoremap <Leader>gg  :Gina<SPACE>
nnoremap <Leader>gh  :Gina patch<CR>
nnoremap <Leader>gl  :Gina log :%<CR>
nnoremap <Leader>gL  :Gina log<CR>
nnoremap <Leader>gM  :Gina merge<SPACE>
nnoremap <Leader>gp  :Gina push<CR>
nnoremap <Leader>gP  :Gina push --force-with-lease<CR>
nnoremap <Leader>gr  :Gina rebase origin/master<CR>
nnoremap <Leader>gR  :Gina remote -v<CR>
nnoremap <Leader>gs  :Gina status<CR>
nnoremap <Leader>gt  :Gina tag<CR>
nnoremap <Leader>gT  :Gina tag<SPACE>
nnoremap <Leader>gu  :Gina push -u<SPACE>
nnoremap <Leader>g-  :Gina stash<CR>:e<CR>
nnoremap <Leader>g+  :Gina stash pop<CR>:e<CR>

" Default options for the specific git commands
call gina#custom#command#option(
  \ 'commit', '-v|--verbose'
  \)
call gina#custom#command#option(
  \ 'patch', '--oneside'
  \)
call gina#custom#command#option(
  \ 'patch',
  \ '--opener', 'split'
  \)
call gina#custom#command#option(
  \ 'show',
  \ '--opener', 'split',
  \ '--show-signature'
  \)
call gina#custom#command#option(
  \ '/\%(status\|commit\)',
  \ '-u|--untracked-files'
  \)
call gina#custom#command#option(
  \ 'status',
  \ '-b|--branch'
  \)
call gina#custom#command#option(
  \ '/\%(branch\|commit\|diff\|log\|status\|tag\)',
  \ '--opener', 'split'
  \)
" Custom action aliases for gina buffers
call gina#custom#action#alias(
  \ '/\%(blame\|log\|reflog\)',
  \ 'preview',
  \ 'belowright show:commit:preview',
  \)
call gina#custom#action#alias(
  \ '/\%(blame\|log\|reflog\)',
  \ 'changes',
  \ 'belowright changes:of:preview',
  \)
" Custom key bindings in gina buffers
call gina#custom#mapping#nmap(
  \ 'branch', 'bd',
  \ ':<C-u>call gina#action#call(''branch:delete'')<CR>',
  \ {'noremap': 1, 'silent': 1}
  \)
call gina#custom#mapping#nmap(
  \ 'branch', 'br',
  \ ':<C-u>call gina#action#call(''branch:move:force'')<CR>',
  \ {'noremap': 1, 'silent': 1}
  \)
call gina#custom#mapping#nmap(
  \ 'branch', 'su',
  \ ':<c-u>call gina#action#call(''branch:set-upstream-to'')<cr>',
  \ {'noremap': 1, 'silent': 1}
  \)
call gina#custom#mapping#nmap(
  \ 'branch', 'uu',
  \ ':<c-u>call gina#action#call(''branch:unset-upstream'')<cr>',
  \ {'noremap': 1, 'silent': 1}
  \)
call gina#custom#mapping#nmap(
  \ 'commit', 'gs',
  \ ':<C-u>Gina status<CR>',
  \ {'noremap': 1, 'silent': 1}
  \)
call gina#custom#mapping#nmap(
  \ 'status', 'cc',
  \ ':<C-u>Gina commit<CR>',
  \ {'noremap': 1, 'silent': 1}
  \)
call gina#custom#mapping#nmap(
  \ 'status', 'ga',
  \ ':<C-u>call gina#action#call(''add'')<CR>',
  \ {'noremap': 1, 'silent': 1}
  \)
call gina#custom#mapping#nmap(
  \ '/\%(branch\|log\)', 'co',
  \ ':<C-u>call gina#action#call(''commit:checkout'')<CR>',
  \ {'noremap': 1, 'silent': 1}
  \)
call gina#custom#mapping#nmap(
  \ '/\%(branch\|tag\)', 'ct',
  \ ':<C-u>call gina#action#call(''commit:checkout:track'')<CR>',
  \ {'noremap': 1, 'silent': 1}
  \)
call gina#custom#mapping#nmap(
  \ '/\%(blame\|log\|reflog\)',
  \ 'p',
  \ ':<C-u>call gina#action#call(''preview'')<CR>',
  \ {'noremap': 1, 'silent': 1}
  \)
call gina#custom#mapping#nmap(
  \ '/\%(blame\|log\|reflog\)',
  \ 'c',
  \ ':<C-u>call gina#action#call(''changes'')<CR>',
  \ {'noremap': 1, 'silent': 1}
  \)
" Set options for gina buffers
call gina#custom#execute(
  \ '/\%(ls\|log\|reflog\|grep\)',
  \ 'setlocal noautoread',
  \)
call gina#custom#execute(
  \ '/\%(status\|branch\|ls\|log\|reflog\|grep\)',
  \ 'setlocal cursorline',
  \)
call gina#custom#execute(
  \ 'commit',
  \ 'setlocal spell',
  \)
call gina#custom#execute(
  \ 'commit',
  \ 'setlocal textwidth=72',
  \)
call gina#custom#execute(
  \ 'log',
  \ 'setlocal number',
  \)
